@@ -10,8 +10,13 @@
 #' @param station_labs logical, should stations be labeled? Defaults to \code{TRUE}
 #' @param lab_loc chr vector of 'R' and 'L', one letter for each station. if no \code{lab_loc} is specified then labels will default to the left.
 ## #' @param scale_pos a vector of x and y values for scalebar location, *e.g.*, `c( "left", "bottom")`, the default.  Enter `scale_pos = NULL` for none. See `help(tm_scale_bar` for additional options.
-#' @param bg_map a georeferenced \code{ggmap} or \code{ggplot} object used as a background map, generally provided by a call to \code{\link{base_map}}. If \code{bg_map} is specified, \code{maptype} and \code{zoom} are ignored.
-#' @param maptype Background map type from Stamen Maps (\url{http://maps.stamen.com/}); one of c("terrain", "terrain-background", "terrain-labels", "terrain-lines", "toner", "toner-2010", "toner-2011", "toner-background", "toner-hybrid", "toner-labels", "toner-lines", "toner-lite", "watercolor").
+#' @param bg_map a georeferenced \code{ggmap} or \code{ggplot} object used as a background map, generally provided by a call to \code{base_map}. If \code{bg_map} is specified, \code{maptype} and \code{zoom} are ignored.
+#' @param maptype Background map type from Stadia Maps (formerly Stamen)
+#'   (\url{https://docs.stadiamaps.com/}); one of c("stamen_terrain",
+#'   "stamen_toner", "stamen_toner_lite", "stamen_watercolor", "alidade_smooth",
+#'   "alidade_smooth_dark", "outdoors", "stamen_terrain_background",
+#'   "stamen_toner_background", "stamen_terrain_labels", "stamen_terrain_lines",
+#'   "stamen_toner_labels", "stamen_toner_lines").
 #' @param zoom Zoom level for the base map created when \code{bg_map} is not specified.  An integer value, 5 - 15, with higher numbers providing  more detail.  If not provided, a zoom level is autoscaled based on \code{bbox} parameters.
 #'
 #' @importFrom ggimage geom_image
@@ -67,7 +72,7 @@
 #' ### Different maptypes may be used.
 #' x_terrain <- res_sk_map('elk', stations = stns, sk_result = trnds,
 #'                  bbox = bounding_elk, shp = shp_fl,
-#'                  maptype = 'terrain')
+#'                  maptype = 'stamen_terrain')
 
 #' ### A multicomponent reserve (showing two different bounding boxes)
 #'
@@ -99,7 +104,7 @@ res_sk_map <- function(nerr_site_id
                        , lab_loc = NULL
                        , bg_map = NULL
                        , zoom = NULL
-                       , maptype = "toner-lite") {
+                       , maptype = "stamen_toner_lite") {
 
   # define local variables  to remove `check()` warnings
   abbrev <- lab_long <- lab_lat <- Latitude <- Longitude <- NULL
